@@ -55,9 +55,10 @@ def main() -> None:
                 continue
             if not dirname.startswith('ucs'):
                 continue
-            if len(dirname) != 6:
+            if len(dirname) not in (6, 7):
                 raise Exception(f'unexpected dirname length: {dirname}')
-            major, minor, patchlevel = (int(x) for x in dirname[3:])
+            major, minor = int(dirname[3]), int(dirname[4])
+            patchlevel = int(dirname[5:])
             releases.append((major, minor, patchlevel))
 
     gen_releases(args.repodir, releases)
