@@ -1,4 +1,4 @@
-#!/usr/share/ucs-test/runner pytest-3 -s -l -vv
+#!/usr/share/ucs-test/runner /usr/share/ucs-test/playwright
 ## desc: Test portal keycloak self service features
 ## tags: [keycloak]
 ## roles: [domaincontroller_master, domaincontroller_backup]
@@ -6,15 +6,12 @@
 ## packages: [univention-self-service]
 ## apps: [keycloak]
 
-from selenium.webdriver.common.by import By
-from utils import wait_for_class, wait_for_id
-
 
 def test_login_denied_if_not_verified(keycloak_settings, portal_login_via_keycloak, unverified_user, portal_config, keycloak_config, change_app_setting):
     change_app_setting('keycloak', {'ucs/self/registration/check_email_verification': True})
-    driver = portal_login_via_keycloak(unverified_user.username, unverified_user.password, verify_login=False)
-    error = wait_for_class(driver, 'ucs-p')[0]
-    error_msg = error.get_attribute('innerHTML')
+    page = portal_login_via_keycloak(unverified_user.username, unverified_user.password, verify_login=False)
+    error = page.locator(".ucs-p")
+    error_msg = error.inner_html()
     expected_msg = (
         keycloak_settings['keycloak/login/messages/en/accountNotVerifiedMsg'].replace('/>', '>').encode('unicode-escape').replace(b'\\\\u', b'\\u').decode('unicode-escape')
     )
@@ -22,9 +19,9 @@ def test_login_denied_if_not_verified(keycloak_settings, portal_login_via_keyclo
     # verify
     unverified_user.verify()
     # try again
-    driver.find_element(By.CSS_SELECTOR, "input[class='pf-c-button pf-m-primary pf-m-block btn-lg']").click()
+    page.click("input[class='pf-c-button pf-m-primary pf-m-block btn-lg']")
     # verify that we are in the portal now
-    wait_for_id(driver, portal_config.header_menu_id)
+    page.locator(f"[id='{portal_config.header_menu_id}']")
 
 
 def test_verified_msg(change_app_setting, unverified_user, portal_login_via_keycloak):
@@ -34,8 +31,8 @@ def test_verified_msg(change_app_setting, unverified_user, portal_login_via_keyc
         'ucs/self/registration/check_email_verification': True,
     }
     change_app_setting('keycloak', settings)
-    driver = portal_login_via_keycloak(unverified_user.username, unverified_user.password, verify_login=False)
-    error = wait_for_class(driver, 'ucs-p')[0]
-    error_msg = error.get_attribute('innerHTML')
+    page = portal_login_via_keycloak(unverified_user.username, unverified_user.password, verify_login=False)
+    error = page.locator(".ucs-p")
+    error_msg = error.inner_text()
     assert error_msg == 'en yada yada yada'
-    driver.find_element(By.CSS_SELECTOR, "input[class='pf-c-button pf-m-primary pf-m-block btn-lg']")
+    page.locator("input[class='pf-c-button pf-m-primary pf-m-block btn-lg']")
