@@ -1,3 +1,9 @@
+# Like what you see? Join us!
+# https://www.univention.com/about-us/careers/vacancies/
+#
+# SPDX-FileCopyrightText: 2024 Univention GmbH
+# SPDX-License-Identifier: AGPL-3.0-only
+
 """Format UCS Test results as simple text report."""
 
 import curses
@@ -13,7 +19,7 @@ from univention.testing.codes import MAX_MESSAGE_LEN
 from univention.testing.data import TestCase, TestEnvironment, TestFormatInterface, TestResult
 
 
-__all__ = ['Text', 'Raw']
+__all__ = ['Raw', 'Text']
 
 
 class _Term:  # pylint: disable-msg=R0903
