@@ -246,6 +246,16 @@ class ADConnection(LDAPConnection):
         no_starttls = ucr.is_false('%s/ad/ldap/ssl' % configbase)
         self.connect(no_starttls)
 
+    def search(self, ldap_filter, attr=[], required=False):
+        res = self.lo.search_ext_s(self.adldapbase, ldap.SCOPE_SUBTREE, ldap_filter, attr, timeout=10)
+        result = []
+        for dn, attr in res:
+            if dn:
+                result.append((dn, attr))
+        if not result and required:
+            raise ldap.NO_SUCH_OBJECT({'desc': 'no object'})
+        return result
+
     def get(self, dn, attr=[], required=False):
         """returns ldap object"""
         if dn:
@@ -327,6 +337,23 @@ class ADConnection(LDAPConnection):
         self.create(new_dn, new_attributes)
         return new_dn
 
+    def windows_create(self, name, position=None, **attributes):
+        """
+        Create a AD windows with attributes as given by the keyword-args
+        `attributes`. The created windows will be populated with some defaults if
+        not otherwise set.
+
+        Returns the dn of the created windows.
+        """
+        new_position = position or 'cn=Computers,%s' % self.adldapbase
+        new_dn = f'cn={ldap.dn.escape_dn_chars(name)},{new_position}'
+
+        defaults = (('userAccountControl', [b'4098']), ('objectclass', [b'top', b'person', b'organizationalPerson', b'user', b'computer']), ('cn', to_bytes(name)))
+        new_attributes = dict(defaults)
+        new_attributes.update(attributes)
+        self.create(new_dn, new_attributes)
+        return new_dn
+
     def getprimarygroup(self, user_dn):
         try:
             res = self.lo.search_ext_s(user_dn, ldap.SCOPE_BASE, timeout=10)
@@ -380,7 +407,9 @@ class ADConnection(LDAPConnection):
         if description:
             attrs['description'] = to_bytes(description)
 
-        self.create(f'ou={ldap.dn.escape_dn_chars(name)},{position}', attrs)
+        dn = f'ou={ldap.dn.escape_dn_chars(name)},{position}'
+        self.create(dn, attrs)
+        return dn
 
     def verify_object(self, dn, expected_attributes):
         """
