@@ -32,6 +32,7 @@
 
 from __future__ import annotations
 
+import contextlib
 import functools
 import logging
 import os
@@ -355,6 +356,27 @@ def restart_listener() -> None:
     subprocess.call(('systemctl', 'restart', 'univention-directory-listener'))
 
 
+def stop_adconnector() -> None:
+    subprocess.check_call(['systemctl', 'stop', 'univention-ad-connector'])
+
+
+def start_adconnector() -> None:
+    subprocess.check_call(['systemctl', 'start', 'univention-ad-connector'])
+
+
+def restart_adconnector() -> None:
+    subprocess.check_call(['systemctl', 'restart', 'univention-ad-connector'])
+
+
+@contextlib.contextmanager
+def adconnector_stopped():
+    try:
+        stop_adconnector()
+        yield
+    finally:
+        start_adconnector()
+
+
 def restart_firewall() -> None:
     subprocess.call((FIREWALL_INIT_SCRIPT, 'restart'))
 
